# Carehome
A stupidly named package for creating MOO-style objects with Python.

Objects support multiple inheritance, properties and methods. The resulting database can be dumped and loaded to and from dictionary objects.
